==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-spanish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Todos los Tpicos");
define("_NOCOMMENTS","Sin Comentarios");
define("_UCOMMENT","Comentario");
define("_REVIEWS","Reviews");
define("_SEARCHUSERS","Buscar Usuarios");
define("_SEARCHSECTIONS","Buscar en Secciones Especiales");
define("_SEARCHREVIEWS","Buscar en Reviews");
define("_SEARCHIN","Buscar en");
define("_ARTICLES","Artculos");
define("_ALLAUTHORS","Todos los Autores");
define("_ALL","Todo");
define("_WEEK","Semana");
define("_WEEKS","Semanas");
define("_MONTH","Mes");
define("_MONTHS","Meses");
define("_SEARCHON","Buscar en");
define("_SSTORIES","Noticias");
define("_SSECTIONS","Secciones");
define("_SUSERS","Usuarios");
define("_NOMATCHES","No hay registros para su consulta");
define("_PREVMATCHES","Registros Anteriores");
define("_NEXTMATCHES","Registros Siguientes");
define("_INSECTION","en la Seccin");
define("_NONAME","No has introducido un nombre");
define("_SCOMMENTS","Comentarios");
define("_SEARCHRESULTS","Resultados de la Bsqueda");
define("_CONTRIBUTEDBY","Contribucin de");
define("_UCOMMENTS","Comentarios");
define("_MATCHTITLE","Buscar por Ttulo");
define("_MATCHTEXT","Buscar por Contenido");
define("_MATCHBOTH","Buscar por Ambos");
define("_SREPLY","responden");
define("_SREPLIES","responde");
define("_ATTACHART","Adjuntar al Artculo");
define("_PAGES","Pginas");
define("_REVIEWSCORE","Puntuacin de este Review");
define("_PAGE","pgina(s) ");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-spanish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Todos los Tpicos");
define("_NOCOMMENTS","Sin Comentarios");
define("_UCOMMENT","Comentario");
define("_REVIEWS","Reviews");
define("_SEARCHUSERS","Buscar Usuarios");
define("_SEARCHSECTIONS","Buscar en Secciones Especiales");
define("_SEARCHREVIEWS","Buscar en Reviews");
define("_SEARCHIN","Buscar en");
define("_ARTICLES","Artculos");
define("_ALLAUTHORS","Todos los Autores");
define("_ALL","Todo");
define("_WEEK","Semana");
define("_WEEKS","Semanas");
define("_MONTH","Mes");
define("_MONTHS","Meses");
define("_SEARCHON","Buscar en");
define("_SSTORIES","Noticias");
define("_SSECTIONS","Secciones");
define("_SUSERS","Usuarios");
define("_NOMATCHES","No hay registros para su consulta");
define("_PREVMATCHES","Registros Anteriores");
define("_NEXTMATCHES","Registros Siguientes");
define("_INSECTION","en la Seccin");
define("_NONAME","No has introducido un nombre");
define("_SCOMMENTS","Comentarios");
define("_SEARCHRESULTS","Resultados de la Bsqueda");
define("_CONTRIBUTEDBY","Contribucin de");
define("_UCOMMENTS","Comentarios");
define("_MATCHTITLE","Buscar por Ttulo");
define("_MATCHTEXT","Buscar por Contenido");
define("_MATCHBOTH","Buscar por Ambos");
define("_SREPLY","responden");
define("_SREPLIES","responde");
define("_ATTACHART","Adjuntar al Artculo");
define("_PAGES","Pginas");
define("_REVIEWSCORE","Puntuacin de este Review");
define("_PAGE","pgina(s) ");

?>
